pub struct WindowMeta {
pub pipeline: String,
pub start: OffsetDateTime,
pub end: OffsetDateTime,
}Expand description
Metadata describing the time window a batch of records belongs to.
Fields
pipeline: StringPipeline (collector) name; used for partitioning storage paths.
start: OffsetDateTimeStart of the window the records were collected in.
end: OffsetDateTimeEnd of the window (the time the batch was handed over).